@@ -1,4 +1,4 @@
-use graplot::{Plot, x};
+use graplot::{x, Plot};
 
 fn main() {
     let plot = Plot::new((|x: f64| x.tanh(), x(6.)));
