@@ -2,8 +2,10 @@ mod bar;
 mod pie;
 mod plot;
 mod scatter;
+mod plot3d;
 
 pub use bar::*;
 pub use pie::*;
 pub use plot::*;
-pub use scatter::*;
\ No newline at end of file
+pub use scatter::*;
+pub use plot3d::*;
\ No newline at end of file
